@@ -47,7 +47,7 @@ check_names_df.logical <- function(j, x) {
   if (!(length(j) %in% c(1L, length(x)))) {
     stopc(
       "Length of logical index vector must be 1 or ", length(x),
-      " (the number of rows), not ", length(j)
+      " (the number of columns), not ", length(j)
     )
   }
   if (anyNA(j)) {
@@ -76,7 +76,7 @@ check_names_before_after.character <- function(j, names) {
   check_needs_no_dim(j)
 
   pos <- safe_match(j, names)
-  if(anyNA(pos)) {
+  if (anyNA(pos)) {
     unknown_names <- j[is.na(pos)]
     stopc(pluralise_msg("Column(s) ", unknown_names), " not found")
   }
