@@ -39,7 +39,7 @@ test_that("properly handles poly class (#110)", {
   p_df <- as_tibble(p)
 
   expect_equal(names(p_df), colnames(p))
-  expect_equal(class(p_df[[1L]]), class(p[,1]))
+  expect_equal(class(p_df[[1L]]), class(p[, 1]))
 })
 
 test_that("handles atomic vectors", {
@@ -65,13 +65,43 @@ test_that("handles atomic vectors", {
 })
 
 test_that("auto-assigning names", {
-  expect_identical(as_tibble(diag(3L)),
-                   as_tibble(as.data.frame(diag(3L))))
+  expect_identical(
+    as_tibble(diag(3L)),
+    as_tibble(as.data.frame(diag(3L)))
+  )
 })
 
 test_that("forwarding to as.data.frame() for ts objects (#184)", {
   mts <- cbind(
     A = ts(c(1, 1, 2, 2),     start = 2016, freq = 4),
-    B = ts(c(11, 11, 12, 13), start = 2016, freq = 4))
+    B = ts(c(11, 11, 12, 13), start = 2016, freq = 4)
+  )
   expect_identical(as_tibble(mts), as_tibble(as.data.frame(mts)))
 })
+
+
+test_that("converting from matrix removes row names by default", {
+  x <- matrix(1:30, 6, 5, dimnames = list(letters[1:6], LETTERS[1:5]))
+  df <- data.frame(A = 1:6, B = 7:12, C = 13:18, D = 19:24, E = 25:30)
+  out <- as_tibble(x)
+  expect_false(has_rownames(out))
+  expect_identical(out, as_tibble(df))
+})
+
+test_that("converting from matrix keeps row names if argument has them, with rownames = NA", {
+  x <- matrix(1:30, 6, 5, dimnames = list(letters[1:6], LETTERS[1:5]))
+  df <- data.frame(
+    A = 1:6, B = 7:12, C = 13:18, D = 19:24, E = 25:30,
+    row.names = letters[1:6]
+  )
+  out <- as_tibble(x, rownames = NA)
+  expect_identical(rownames(out), rownames(x))
+  expect_identical(out, as_tibble(df))
+})
+
+test_that("converting from matrix supports storing row names in a column", {
+  x <- matrix(1:30, 6, 5, dimnames = list(letters[1:6], LETTERS[1:5]))
+  df <- tibble(id = letters[1:6], A = 1:6, B = 7:12, C = 13:18, D = 19:24, E = 25:30)
+  out <- as_tibble(x, rownames = "id")
+  expect_identical(out, df)
+})
